pub enum Literal<'a> {
Number(f64),
String(&'a str),
Concat(Box<Literal<'a>>, Box<Literal<'a>>),
True,
False,
Nil,
Void,
List(Vec<Literal<'a>>),
}Expand description
A literal value
Variants
Number(f64)
A number
String(&'a str)
A string
Concat(Box<Literal<'a>>, Box<Literal<'a>>)
Concatenated strings
True
Boolean true
False
Boolean false
Nil
NULL
Void
A void return
List(Vec<Literal<'a>>)
A list of expressions
Implementations
Sourceimpl<'a> Literal<'a>
impl<'a> Literal<'a>
Sourcepub fn uint(&self) -> Result<usize, RuntimeError>
pub fn uint(&self) -> Result<usize, RuntimeError>
Returns the inner literal if it’s a proper unsigned integer truly, asserting a runtime error if not
Sourcepub fn number(&self) -> Result<f64, RuntimeError>
pub fn number(&self) -> Result<f64, RuntimeError>
Returns the inner literal if it’s numeric, asserting a runtime error if not
Sourcepub fn bool(&self) -> Result<bool, RuntimeError>
pub fn bool(&self) -> Result<bool, RuntimeError>
Returns the inner literal if it’s boolean, asserting a runtime error if not
Sourcepub fn equals(&self, other: &Self) -> Result<Literal<'a>, RuntimeError>
pub fn equals(&self, other: &Self) -> Result<Literal<'a>, RuntimeError>
Returns the True literal if the two literals are losely equal
Sourcepub fn not_equals(&self, other: &Self) -> Result<Literal<'a>, RuntimeError>
pub fn not_equals(&self, other: &Self) -> Result<Literal<'a>, RuntimeError>
Returns the True literal if the two literals are not losely equal